'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-bdeef4f4.js');
const defaultIconPack = require('./default-icon-pack-0ea0e986.js');
const index$1 = require('./index-dbc5b08f.js');
require('./default-language-4c779255.js');

const dyteRecordingToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const DyteRecordingToggle = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Variant */
    this.variant = 'button';
    /** Language */
    this.t = index$1.useLanguage();
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    this.canRecord = false;
    this.toggleRecording = () => {
      var _a, _b;
      if (this.isLoading())
        return;
      switch (this.recordingState) {
        case 'IDLE':
          (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.recording.start();
          return;
        case 'RECORDING':
          (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.recording.stop();
          return;
        case 'STARTING':
        case 'STOPPING':
        default:
          return;
      }
    };
    this.isLoading = () => {
      return (this.meeting == null ||
        this.recordingState === 'STARTING' ||
        this.recordingState === 'STOPPING');
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.recordingStateUpdateListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.recording.removeListener('recordingUpdate', this.recordingStateUpdateListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.recordingState = meeting.recording.recordingState;
      this.canRecord = meeting.self.permissions.canRecord === true;
      this.recordingStateUpdateListener = (recordingState) => {
        this.recordingState = recordingState;
      };
      meeting.recording.addListener('recordingUpdate', this.recordingStateUpdateListener);
    }
  }
  getLabel() {
    switch (this.recordingState) {
      case 'IDLE':
        return this.t('Record');
      case 'RECORDING':
        return this.t('Stop Recording');
      case 'STARTING':
        return this.t('Starting');
      case 'STOPPING':
        return this.t('Stopping');
      default:
        return this.t('Loading');
    }
  }
  getIcon() {
    switch (this.recordingState) {
      case 'IDLE':
        return this.iconPack.recording;
      case 'RECORDING':
        return this.iconPack.stop_recording;
      case 'STARTING':
      case 'STOPPING':
      default:
        return this.iconPack.recording;
    }
  }
  render() {
    if (!this.canRecord)
      return;
    return (index.h(index.Host, { title: this.t('Record') }, index.h("dyte-controlbar-button", { size: this.size, iconPack: this.iconPack, onClick: this.toggleRecording, icon: this.getIcon(), isLoading: this.isLoading(), label: this.t(this.getLabel()), variant: this.variant })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteRecordingToggle.style = dyteRecordingToggleCss;

exports.dyte_recording_toggle = DyteRecordingToggle;
