import { Component, Host, h, Prop } from '@stencil/core';
/**
 * A button that follows Dyte's Design System.
 *
 * @slot - Default slot
 * @slot start - Content placed to the start of the button, i.e; left.
 * @slot end - Content placed to the end of the button, i.e; right.
 */
export class DyteButton {
  constructor() {
    /** Button variant */
    this.variant = 'primary';
    /** Button type */
    this.kind = 'button';
    /** Whether to reverse order of children */
    this.reverse = false;
    /** Where the button is disabled or not */
    this.disabled = false;
  }
  render() {
    return (h(Host, null,
      h("button", { part: "button" },
        h("span", { class: "start" },
          h("slot", { name: "start" })),
        h("span", { class: "content", part: "content" },
          h("slot", null)),
        h("span", { class: "end" },
          h("slot", { name: "end" })))));
  }
  static get is() { return "dyte-button"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-button.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-button.css"]
  }; }
  static get properties() { return {
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ButtonVariant",
        "resolved": "\"danger\" | \"ghost\" | \"primary\" | \"secondary\"",
        "references": {
          "ButtonVariant": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Button variant"
      },
      "attribute": "variant",
      "reflect": true,
      "defaultValue": "'primary'"
    },
    "kind": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ButtonKind",
        "resolved": "\"button\" | \"icon\" | \"wide\"",
        "references": {
          "ButtonKind": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Button type"
      },
      "attribute": "kind",
      "reflect": true,
      "defaultValue": "'button'"
    },
    "reverse": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether to reverse order of children"
      },
      "attribute": "reverse",
      "reflect": true,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Where the button is disabled or not"
      },
      "attribute": "disabled",
      "reflect": true,
      "defaultValue": "false"
    }
  }; }
}
