import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$2 } from './dyte-icon2.js';

const dyteParticipantCountCss = ":host{display:inline-flex;height:var(--dyte-space-10, 40px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;align-items:center;padding:var(--dyte-space-1, 4px);font-family:var(--dyte-font-family, sans-serif)}dyte-icon{margin-right:var(--dyte-space-1, 4px);height:var(--dyte-space-5, 20px);width:var(--dyte-space-5, 20px)}";

const DyteParticipantCount$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.participantCount = 0;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    if (this.meeting != null && this.countListener != null) {
      this.meeting.participants.joined.removeListener('participantJoined', this.countListener);
      this.meeting.participants.joined.removeListener('participantLeft', this.countListener);
    }
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.countListener = () => {
        this.participantCount =
          meeting.participants.joined.size + (meeting.self.roomJoined ? 1 : 0);
      };
      this.countListener();
      meeting.participants.joined.addListener('participantJoined', this.countListener);
      meeting.participants.joined.addListener('participantLeft', this.countListener);
    }
  }
  render() {
    return (h(Host, { tabIndex: 0, role: "log", "aria-label": `${this.participantCount} ${this.t('participants')}` }, h("dyte-icon", { icon: this.iconPack.people, tabIndex: -1, "aria-hidden": true, part: "icon" }), this.participantCount));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteParticipantCountCss; }
}, [1, "dyte-participant-count", {
    "meeting": [16],
    "iconPack": [16],
    "t": [16],
    "participantCount": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-participant-count", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-participant-count":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteParticipantCount$1);
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteParticipantCount = DyteParticipantCount$1;
const defineCustomElement = defineCustomElement$1;

export { DyteParticipantCount, defineCustomElement };
