import { h, proxyCustomElement, HTMLElement, Host } from '@stencil/core/internal/client';
import { h as hasOnlyEmojis } from './string.js';
import { C as ChatHead } from './ChatHead.js';

const URLRegEx = /(https?:\/\/[^\s]+)/;
const formatMessage = (text) => {
  const words = text.split(' ');
  const lastIndex = words.length - 1;
  return words.map((word, index) => {
    if (URLRegEx.test(word)) {
      return (h("span", null,
        h("a", { href: word, target: "_blank", rel: "noopener noreferrer" }, word),
        index !== lastIndex ? ' ' : ''));
    }
    return `${word}${index !== lastIndex ? ' ' : ''}`;
  });
};
const TextMessageView = ({ message }) => {
  const lines = message.split('\n');
  return lines.map((line) => h("p", null, formatMessage(line)));
};

const DyteTextMessage = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** Date object of now, to calculate distance between dates */
    this.now = new Date();
    /** Whether the message is continued by same user */
    this.isContinued = false;
  }
  render() {
    return (h(Host, null, !this.isContinued && (h(ChatHead, { name: this.message.displayName, time: this.message.time, now: this.now })), h("div", { class: "body", part: "body" }, h("div", { class: { text: true, emoji: hasOnlyEmojis(this.message.message) } }, h(TextMessageView, { message: this.message.message })))));
  }
}, [0, "dyte-text-message", {
    "message": [16],
    "now": [16],
    "isContinued": [516, "is-continued"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-text-message"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-text-message":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteTextMessage);
      }
      break;
  } });
}

export { DyteTextMessage as D, defineCustomElement as d };
